@@ -3,6 +3,7 @@
 #include <QMetaMethod>
 #include <QLocalSocket>
 #include <QTcpSocket>
+#include <QFileInfo>
 #include "msgpackrequest.h"
 #include "neovimconnectorhelper.h"
 #include "msgpackiodevice.h"
@@ -85,6 +86,20 @@ QString NeovimConnector::errorString()
 	return m_errorString;
 }
 
+QString NeovimConnector::connectionDescription()
+{
+	switch (m_ctype) {
+		case SpawnedConnection:
+			return m_spawnExe + " " + m_spawnArgs.join(" ");
+		case HostConnection:
+			return m_connHost + ":" + m_connPort;
+		case SocketConnection:
+			return m_connSocket;
+		default:
+			return "";
+	}
+}
+
 /**
  * Returns the channel id used by Neovim to identify this connection
  */
@@ -278,7 +293,7 @@ NeovimConnector* NeovimConnector::spawn(const QStringList& params, const QString
 
 	connect(p, SIGNAL(error(QProcess::ProcessError)),
 			c, SLOT(processError(QProcess::ProcessError)));
-	connect(p, SIGNAL(finished(int, QProcess::ExitStatus)),
+	connect(p, SIGNAL(finished(int,QProcess::ExitStatus)),
 			c, SIGNAL(processExited(int)));
 	connect(p, &QProcess::started,
 			c, &NeovimConnector::discoverMetadata);
@@ -297,15 +312,20 @@ NeovimConnector* NeovimConnector::connectToSocket(const QString& path)
 {
 	QLocalSocket *s = new QLocalSocket();
 	NeovimConnector *c = new NeovimConnector(s);
-
 	c->m_ctype = SocketConnection;
+#if defined(Q_OS_UNIX)
+	// #936: Qt assumes paths relative to /tmp
+	// https://bugreports.qt.io/browse/QTBUG-50877
+	c->m_connSocket = QFileInfo(path).absoluteFilePath();
+#else
 	c->m_connSocket = path;
+#endif
 
 	connect(s, SIGNAL(error(QLocalSocket::LocalSocketError)),
 			c, SLOT(socketError()));
 	connect(s, &QLocalSocket::connected,
 			c, &NeovimConnector::discoverMetadata);
-	s->connectToServer(path);
+	s->connectToServer(c->m_connSocket);
 	return c;
 }
 
@@ -353,7 +373,7 @@ NeovimConnector* NeovimConnector::connectToNeovim(const QString& server)
 	int colon_pos = addr.lastIndexOf(':');
 	if (colon_pos != -1 && colon_pos != 0 && addr[colon_pos-1] != ':') {
 		bool ok;
-		int port = addr.mid(colon_pos+1).toInt(&ok);
+		int port = addr.midRef(colon_pos+1).toInt(&ok);
 		if (ok) {
 			QString host = addr.mid(0, colon_pos);
 			return connectToHost(host, port);
